@@ -3,7 +3,7 @@ package Dist::Inkt;
 use 5.010001;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use Moose;
 use Module::Metadata;
@@ -164,6 +164,9 @@ sub BuildManifest
 	
 	my $file = $self->targetfile('MANIFEST');
 	$self->log("Writing $file");
+	$self->rights_for_generated_files->{'MANIFEST'} ||= [
+		'None', 'public-domain'
+	] if $self->DOES('Dist::Inkt::Role::WriteCOPYRIGHT');
 	
 	my $rule = 'Path::Iterator::Rule'->new->file;
 	my $root = $self->targetdir;
