@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::SignDistribution;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use Moose::Role;
 use Module::Signature ();
@@ -21,6 +21,9 @@ sub Build_SIGNATURE
 	my $file = $self->targetfile('SIGNATURE');
 	$file->exists and return $self->log('Skipping %s; it already exists', $file);
 	$self->log('Writing %s', $file);
+	$self->rights_for_generated_files->{'SIGNATURE'} ||= [
+		'None', 'public-domain'
+	] if $self->DOES('Dist::Inkt::Role::WriteCOPYRIGHT');
 	$file->spew('placeholder');
 }
 
