@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::WriteCREDITS;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -30,6 +30,9 @@ sub Build_CREDITS
 	my $file = $self->targetfile('CREDITS');
 	$file->exists and return $self->log('Skipping %s; it already exists', $file);
 	$self->log('Writing %s', $file);
+	$self->rights_for_generated_files->{'CREDITS'} ||= [
+		'None', 'public-domain'
+	] if $self->DOES('Dist::Inkt::Role::WriteCOPYRIGHT');
 	
 	my $fh = $file->openw_utf8;
 	
